/**
 *  @file       BasicDisplayFunctions.ino
 *  Project     Anclk display library
 *  @brief      An Arduino library for custom made JSC electronics ANCLK display.
 *  @author     Robert Faltus for JSC electronics s.r.o.
 *  License     Apache-2.0 - Copyright (c) 2022 – 2023 JSC electronics
 *
 *  Copyright (c) 2022 – 2023 JSC electronics
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * Example BasicDisplayFunctions.ino
 * Demonstrates the basic display functionality.
 */

#include "Arduino.h"
#include "AnclkDisplay.h"
#include "Defines.h"

AnclkDisplay anclk = AnclkDisplay(DEFAULT_ADR_IC7, DEFAULT_ADR_IC2, DEFAULT_ADR_IC4);

void setup()
{
    Serial.begin(9600);
    delay(10);

    anclk.begin();
}

void loop()
{
  bool toggle = true;

  anclk.displayClear();
  for (int i = 1; i < 5; i++) {
    anclk.displayDot(i, toggle);
    delay(500);
  }
  anclk.displayClear();
  
  toggle = true;
  for (int i = 0; i < 6; i++) {

    anclk.displayColon(toggle);
    toggle = !toggle;
    delay(500);
  }
  anclk.displayClear();

  anclk.displaySymbol(NUM_1, AnclkDisplay::DisplayEnum::DISP1);
  anclk.displaySymbol(NUM_2, AnclkDisplay::DisplayEnum::DISP2);
  anclk.displaySymbol(NUM_3, AnclkDisplay::DisplayEnum::DISP3);
  anclk.displaySymbol(NUM_4, AnclkDisplay::DisplayEnum::DISP4);
  delay(3000);

  anclk.displayClear();
  anclk.displaySymbol(NUM_5, AnclkDisplay::DisplayEnum::DISP1);
  anclk.displaySymbol(NUM_6, AnclkDisplay::DisplayEnum::DISP2);
  anclk.displaySymbol(NUM_7, AnclkDisplay::DisplayEnum::DISP3);
  anclk.displaySymbol(NUM_8, AnclkDisplay::DisplayEnum::DISP4);
  delay(3000);

  anclk.showNumber(8526);
  delay(3000);

  // switch OUT1 ON
  anclk.activateOutput(AnclkDisplay::PowerOutput::OUT1, true);
  delay(3000);
  anclk.activateOutput(AnclkDisplay::PowerOutput::OUT1, false);
  delay(3000);
}
