/**
 *  @file       Defines.h
 *  Project     Anclk display library
 *  @brief      An Arduino library for custom made JSC electronics ANCLK display.
 *  @author     Ales Svoboda
 *  License     Apache-2.0 - Copyright (c) 2022 – 2024 JSC electronics
 *  @version    v1.0
 *
 *  Copyright (c) 2022 – 2023 JSC electronics
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef ANCLK_DEF_H
#define ANCLK_DEF_H

//////////////////////////////////////////////////////////////////////////////////////////////////
////ANCLK DISPLAY CONSTANTS

#define DEFAULT_ADR_IC7         0x20
#define DEFAULT_ADR_IC2         0x21
#define DEFAULT_ADR_IC4         0x22  

#define INIT_PORT_VAL           0x00

#define NUM_OF_DISPLAYS         4       // num of displays
#define NUM_OF_SEGMENTS         8       // A to G + DP

//////////////////////////////////////////////////////////////////////////////////////////////////
////CLOCK CONSTANTS

#define T1_MAX_THRESH           99
#define T2_MAX_SEC_MIN_THRESH   59
#define T2_MAX_TENTHS_THRESH    90

////CLOCK CONSTANTS
//////////////////////////////////////////////////////////////////////////////////////////////////

//////////////////////////////////////////////////////////////////////////////////////////////////
////MACROS

#define MC_DEC_PL_DEVIDER(decPl) (decPl > 0) ? pow(10, decPl) : 1;

////MACROS
//////////////////////////////////////////////////////////////////////////////////////////////////

//////////////////////////////////////////////////////////////////////////////////////////////////
////PINS

#define ANCLK_IO_D0             0
#define ANCLK_IO_D1             1
#define ANCLK_IO_D2             2
#define ANCLK_IO_D3             3
#define ANCLK_IO_D4             4
#define ANCLK_IO_D5             5
#define ANCLK_IO_D6             6
#define ANCLK_IO_D7             7
#define ANCLK_12V_IN_D8         8
#define ANCLK_12V_IN_D9         9
#define ANCLK_IO_D10            10
#define ANCLK_IO_D11            11
#define ANCLK_IO_D12            12
#define ANCLK_IO_D13            13
#define ANCLK_IO_A0             A0
#define ANCLK_IO_A1             A1
#define ANCLK_IO_A2             A2
#define ANCLK_IO_A3             A3
#define ANCLK_IO_A4             A4
#define ANCLK_IO_A5             A5

////PINS
//////////////////////////////////////////////////////////////////////////////////////////////////

#endif